Skip to contents

file extension

Usage

fex(x)

Arguments

x

character vector giving file paths.

Value

A character vector of the same length as x containing the file extensions without the leading dot. Files without an extension return an empty string ("").

Note

source tools::file_ext

Examples

if (FALSE) { # \dontrun{
# Do not run
} # }